"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeFile = exports.rmdir = exports.mkdir = exports.copyFile = exports.rename = exports.unlink = void 0;
const fs = require("fs");
const elements_1 = require("../elements");
const returnVoid = () => {};

/**
 * Creates a `Command` that calls `fs.promises.unlink()`.
 */
const unlink = (path) =>
  elements_1.cmdEx(async () => fs.promises.unlink(path), `unlink ${path}`);
exports.unlink = unlink;

/**
 * Creates a `Command` that calls `fs.promises.rename()`.
 */
const rename = (oldPath, newPath) =>
  elements_1.cmdEx(
    async () => fs.promises.rename(oldPath, newPath),
    `rename ${oldPath} -> ${newPath}`
  );
exports.rename = rename;

/**
 * Creates a `Command` that calls `fs.promises.unlink()`.
 * @param flags See Node.js docs.
 */
const copyFile = (src, dest, flags) =>
  elements_1.cmdEx(
    async () => fs.promises.copyFile(src, dest, flags),
    `rename ${src} -> ${dest}`
  );
exports.copyFile = copyFile;

/**
 * Creates a `Command` that calls `fs.promises.mkdir()`.
 * @param options See Node.js docs.
 */
const mkdir = (path, options) =>
  elements_1.cmdEx(
    async () => fs.promises.mkdir(path, options).then(returnVoid),
    `mkdir ${path}`
  );
exports.mkdir = mkdir;

/**
 * Creates a `Command` that calls `fs.promises.rmdir()`.
 * @param options See Node.js docs.
 */
const rmdir = (path, options) =>
  elements_1.cmdEx(
    async () => fs.promises.rmdir(path, options).then(returnVoid),
    `rmdir ${path}`
  );
exports.rmdir = rmdir;

/**
 * Creates a `Command` that calls `fs.promises.writeFile()`.
 * @param options See Node.js docs.
 */
const writeFile = (path, data, options) =>
  elements_1.cmdEx(
    async () => fs.promises.writeFile(path, data, options),
    `writeFile ${path}`
  );
exports.writeFile = writeFile;
