"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isMaybeCommand = exports.createCommand = void 0;
const types_1 = require("../types");
const cloneHidden = (command) => {
  const newProps = {
    displayState: types_1.DisplayState.Hidden,
  };
  return Object.assign(Object.create(command), newProps);
};

/** `rename()` method of `Command`. */
const rename = function (name) {
  const newProps = { name };
  return Object.assign(Object.create(this), newProps);
};

/** `ignoreFailure()` method of `Command`. */
const ignoreFailure = function () {
  const newProps = { ignoresFailure: true };
  return Object.assign(Object.create(this), newProps);
};

/** `collapse()` method of `Command`. */
const hide = function () {
  return cloneHidden(this);
};

/** `collapse()` method of `Command`. */
const collapse = function () {
  const { children } = this;
  if (children && children.length) {
    const newProps = {
      children: children.map(cloneHidden),
      displayState: types_1.DisplayState.Collapsed,
    };
    return Object.assign(Object.create(this), newProps);
  } else return this;
};

/** Creates a `Command` instance. */
const createCommand = (params) => ({
  ...params,
  ignoresFailure: false,
  ignoreFailure,
  rename,
  displayState: undefined,
  hide,
  collapse,
});
exports.createCommand = createCommand;
const comparison = exports.createCommand({
  run: () => Promise.resolve(),
  type: types_1.CommandType.Unit,
  subType: types_1.CommandSubType.Null,
  name: "",
});

/** @returns `true` if `obj` is (maybe) a `Command` object. */
//eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
const isMaybeCommand = (obj) => {
  if (!obj) return false;
  if (typeof obj !== "object") return false;
  if (typeof obj.run !== typeof comparison.run) return false;
  if (typeof obj.type !== typeof comparison.type) return false;
  if (typeof obj.subType !== typeof comparison.subType) return false;
  return true;
};
exports.isMaybeCommand = isMaybeCommand;
