"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cmdEx = void 0;
const debug_1 = require("../../debug");
const types_1 = require("../types");
const command_1 = require("./command");

/** `run()` method for `ExternalCommand`. */
const runUnitExternal = function (onEvent) {
  const { runner, name } = this;
  debug_1.traceRun(name);
  const startResult = onEvent(this, types_1.Event.Start);
  if (startResult) return startResult;
  return runner().then(
    () => {
      debug_1.traceDone(name);
      return onEvent(this, types_1.Event.Success);
    },
    (reason) =>
      onEvent(this, types_1.Event.Failure) ||
      (this.ignoresFailure ? Promise.resolve() : Promise.reject(reason))
  );
};

/**
 * Creates a `Command` unit from an external asynchronous function.
 * @param promiserFunc Any function of type `() => Promise<void>`.
 * @param name Name for displaying instead of an actual command line.
 */
const cmdEx = (promiserFunc, name = "(external)") => {
  const base = command_1.createCommand({
    run: runUnitExternal,
    type: types_1.CommandType.Unit,
    subType: types_1.CommandSubType.External,
    name,
  });
  return Object.assign(base, { runner: promiserFunc });
};
exports.cmdEx = cmdEx;
