"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRouter = void 0;
const log_1 = require("../../log");
const runner = require("../runner");
const command_1 = require("../elements/command");
const normalizeKeyCommandMap = (keyCommandMap) => {
  const newMap = new Map();
  for (const [key, command] of Object.entries(keyCommandMap)) {
    if (!command_1.isMaybeCommand(command)) continue;
    newMap.set(key, command);
  }
  return newMap;
};
const createHelp = (keyCommandMap) => () => {
  let maxKeyLength = 4;
  for (const key of keyCommandMap.keys())
    if (maxKeyLength < key.length) maxKeyLength = key.length;
  const keyColumnWidth = maxKeyLength + 2;
  log_1.log("router settings");
  log_1.println("key:".padEnd(keyColumnWidth) + "command:");
  for (const [key, command] of keyCommandMap.entries()) {
    const name = command.name || "(nameless command)";
    log_1.println(" " + key.padEnd(keyColumnWidth) + name);
  }
  log_1.newLine();
};
const emptyRun = async () => {
  const nullResult = new Map();
  return nullResult;
};
const createRun = (keyCommandMap, help, defaultCommand) => (
  key,
  onEvent,
  onSuccessAll,
  onFailureAny
) => {
  const command = keyCommandMap.get(key) || defaultCommand;
  if (command) return runner.run(command, onEvent, onSuccessAll, onFailureAny);
  help();
  return emptyRun();
};

/** Creates a `Router` object. */
const createRouter = (keyCommandMap, defaultCommand) => {
  const commandMap = normalizeKeyCommandMap(keyCommandMap);
  const help = createHelp(commandMap);
  const run = createRun(commandMap, help, defaultCommand);
  return { run, help };
};
exports.createRouter = createRouter;
